# SABER-HBC

SABER (Stream Analysis for Bias Estimation and Reduction) is a bias correction method for modeled discharge first 
presented in the journal article: [https://doi.org/10.3390/hydrology9070113](https://doi.org/10.3390/hydrology9070113).

SABER-HBC (Hydrological Bias Correction) is the authoritative python implementation of the SABER bias correction method.
